@@ -225,7 +225,7 @@ DBSrLabelLoc(rootUse, name, func, cdarg)
     char csave;
     Rect r;
 
-    if (cp = strrchr(name, '/'))
+    if ((cp = strrchr(name, '/')))
     {
 	csave = *cp;
 	*cp = '\0';
