@@ -2,21 +2,21 @@
  *
  *	Initialization for the greedy router.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
 #ifndef lint
-static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic/gcr/gcrInit.c,v 1.1.1.1 2005/05/09 23:29:23 tim Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/gcr/gcrInit.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -47,7 +47,7 @@ float GCRObstDist;	/* Sun lint brain death */
 /* Forward declarations */
 void gcrLinkPin();
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -98,7 +98,7 @@ gcrSetEndDist(ch)
     GCREndDist = (multiTotal/2 + rightTotal/4) * RtrEndConst;
     if (GCREndDist < 1) GCREndDist = 1;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -144,7 +144,7 @@ gcrBuildNets(ch)
 
     HashKill(&ht);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -192,7 +192,7 @@ gcrLinkPin(pin, ht, ch)
 	/* New net */
 	net = (GCRNet *) mallocMagic((unsigned) (sizeof (GCRNet)));
 	HashSetValue(hEntry, (char *) net);
-	net->gcr_Id = (int) pin->gcr_pId;
+	net->gcr_Id = (spointertype) pin->gcr_pId;
 
 	/* Link net onto channel net list */
 	net->gcr_next = ch->gcr_nets;
@@ -212,7 +212,7 @@ gcrLinkPin(pin, ht, ch)
     pin->gcr_pId = net;
     pin->gcr_pNext = (GCRPin *) NULL;
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -236,7 +236,7 @@ gcrUnlinkPin(pin)
 {
     GCRNet *net;
 
-    if (net = pin->gcr_pId)
+    if ((net = pin->gcr_pId))
     {
 	ASSERT(pin == net->gcr_lPin, "gcrUnlinkPin");
 	net->gcr_lPin = pin->gcr_pNext;
@@ -244,7 +244,7 @@ gcrUnlinkPin(pin)
 	    pin->gcr_pNext->gcr_pPrev = pin->gcr_pPrev;
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -320,7 +320,7 @@ gcrDensity(ch)
 
     return (maxVal);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
